@@ -66,13 +66,13 @@ B<active:>  Active shipping destination?  Default is false.
 =head2 show_state
 
   data_type: 'boolean'
-  default_value: false
+  default_value: 0
   is_nullable: 0
 
 =head2 active
 
   data_type: 'boolean'
-  default_value: true
+  default_value: 1
   is_nullable: 0
 
 =cut
@@ -87,9 +87,9 @@ __PACKAGE__->add_columns(
   "priority",
   { data_type => "integer", default_value => 0, is_nullable => 0 },
   "show_states",
-  { data_type => "boolean", default_value => \"false", is_nullable => 0 },
+  { data_type => "boolean", default_value => 0, is_nullable => 0 },
   "active",
-  { data_type => "boolean", default_value => \"true", is_nullable => 0 },
+  { data_type => "boolean", default_value => 1, is_nullable => 0 },
 );
 
 =head1 PRIMARY KEY
