@@ -63,7 +63,6 @@ __PACKAGE__->table("orderlines");
 =head2 description
 
   data_type: 'text'
-  default_value: (empty string)
   is_nullable: 0
 
 =head2 weight
@@ -141,7 +140,7 @@ __PACKAGE__->add_columns(
   "short_description",
   { data_type => "varchar", default_value => "", is_nullable => 0, size => 500 },
   "description",
-  { data_type => "text", default_value => "", is_nullable => 0 },
+  { data_type => "text", is_nullable => 0 },
   "weight",
   { data_type => "numeric", default_value => "0.0", is_nullable => 0, size => [10,3] },
   "quantity",
