@@ -19,7 +19,7 @@ use warnings;
 
 use DateTime;
 
-use parent 'Interchange6::Schema::ResultSet';
+use base 'DBIx::Class::ResultSet';
 
 =head1 METHODS
 
