@@ -11,64 +11,44 @@ test 'simple user tests' => sub {
 
     my $self = shift;
 
-    # make sure there is no mess and stash user fixture count
+    # make sure there is no mess
     $self->clear_users;
-    my $user_count = $self->users->count;
 
-    my $schema = $self->ic6s_schema;
-
-    my $rset_user = $schema->resultset('User');
+    my $rset_user = $self->schema->resultset('User');
 
     my ( $data, $result );
 
-    throws_ok(
-        sub { $rset_user->create( {} ) },
+    throws_ok( sub { $rset_user->create({}) },
         qr/username cannot be unde/,
-        "fail User create with empty hashref"
-    );
+        "fail User create with empty hashref" );
 
-    throws_ok(
-        sub { $rset_user->create( { username => undef } ) },
+    throws_ok( sub { $rset_user->create({ username => undef }) },
         qr/username cannot be unde/,
-        "fail User create with undef username"
-    );
+        "fail User create with undef username" );
 
-    throws_ok(
-        sub { $rset_user->create( { username => 'MixedCase' } ) },
+    throws_ok( sub { $rset_user->create({ username => 'MixedCase' }) },
         qr/username must be lowercase/,
-        "fail User create with mixed case username"
-    );
+        "fail User create with mixed case username" );
 
-    throws_ok(
-        sub { $rset_user->create( { username => '' } ) },
+    throws_ok( sub { $rset_user->create({ username => '' }) },
         qr/username cannot be empty string/,
-        "fail User create with empty string username"
-    );
+        "fail User create with empty string username" );
 
-    lives_ok(
-        sub {
-            $result =
-              $rset_user->create( { username => 'nevairbe@nitesi.de' } );
-        },
-        "create user"
-    );
+    lives_ok( sub {
+            $result = $rset_user->create({ username => 'nevairbe@nitesi.de' })
+        }, "create user" );
 
-    throws_ok(
-        sub { $rset_user->create( { username => 'nevairbe@nitesi.de' } ) },
+    throws_ok( sub { $rset_user->create({ username => 'nevairbe@nitesi.de' }) },
         qr/DBI Exception/i,
-        "fail to create duplicate username"
-    );
+        "fail to create duplicate username" );
 
-    throws_ok(
-        sub { $result->update( { username => 'MixedCase' } ) },
+    throws_ok( sub { $result->update({ username => 'MixedCase' }) },
         qr/username must be lowercase/,
-        "Fail to change username to mixed case"
-    );
+        "Fail to change username to mixed case" );
 
     lives_ok( sub { $result->delete }, "delete user" );
 
-    cmp_ok( $rset_user->count, '==', $user_count, "user count is $user_count" );
-    my $role_count = $schema->resultset('Role')->count;
+    cmp_ok( $rset_user->count, '==', 0, "zero User rows" );
 
     $data = {
         username => 'nevairbe@nitesi.de',
@@ -81,24 +61,6 @@ test 'simple user tests' => sub {
     like( $result->password, qr/^\$2a\$14\$.{53}$/,
         "Check password hash has correct format" );
 
-    cmp_ok( $result->user_roles->count, '==', 1, "user has 1 user_roles" );
-    cmp_ok( $result->roles->first->name, 'eq', 'user', "role is 'user'" );
-    cmp_ok( $rset_user->count, '==', ++$user_count,
-        "we have $user_count users" );
-    cmp_ok( $schema->resultset('UserRole')->count,
-        '==', $user_count, "$user_count user role" );
-    cmp_ok( $schema->resultset('Role')->count,
-        '==', $role_count, "$role_count roles" );
-
-    lives_ok( sub { $result->delete }, "delete user" );
-
-    cmp_ok( $rset_user->count, '==', --$user_count,
-        "we have $user_count users" );
-    cmp_ok( $schema->resultset('UserRole')->count,
-        '==', $user_count, "$user_count user role" );
-    cmp_ok( $schema->resultset('Role')->count,
-        '==', $role_count, "$role_count roles" );
-
     # cleanup
     $self->clear_users;
 };
@@ -163,61 +125,63 @@ test 'user attribute tests' => sub {
 
 test 'user role tests' => sub {
 
-    my $self   = shift;
-    my $schema = $self->ic6s_schema;
-    my $rset_user = $schema->resultset('User');
-
-    # use roles fixture
-    $self->roles;
+    my $self = shift;
 
     my ( $admin1, $admin2 );
-    my $rset_role = $schema->resultset("Role");
 
-    my $role_admin  = $rset_role->find( { name => 'admin' } );
-    my $role_user   = $rset_role->find( { name => 'user' } );
-    my $role_editor = $rset_role->find( { name => 'editor' } );
+    #create roles
+    my $pop_roles = $self->schema->resultset("Role")->populate(
+        [
+            { roles_id => '1', name => 'user',   label => 'Basic User' },
+            { roles_id => '2', name => 'admin',  label => 'Admin User' },
+            { roles_id => '3', name => 'editor', label => 'Editor' },
+        ]
+    );
 
     lives_ok( sub { $admin1 = $self->users->find( { username => 'admin1' } ) },
         "grab admin1 user from fixtures" );
 
-    lives_ok(
-        sub { $admin1->set_roles( [ $role_admin, $role_user, $role_editor ] ) },
-        "Add admin1 to admin, user and editor roles"
-    );
-
     lives_ok( sub { $admin2 = $self->users->find( { username => 'admin2' } ) },
         "grab admin2 user from fixtures" );
 
-    lives_ok( sub { $admin2->set_roles( [ $role_user, $role_editor ] ) },
-        "Add admin2 to user and editor roles" );
+    foreach my $i ( 1 .. 3 ) {
+        lives_ok( sub { $admin1->add_to_user_roles( { roles_id => $i } ) },
+            "add roles_id $i to admin1" );
+    }
+
+    foreach my $i ( 1, 3 ) {
+        lives_ok( sub { $admin2->add_to_user_roles( { roles_id => $i } ) },
+            "add roles_id $i to admin2" );
+    }
 
     # count via m2m
     cmp_ok( $admin1->roles->count, '==', 3, "admin1 has 3 roles" );
     cmp_ok( $admin2->roles->count, '==', 2, "admin2 has 2 roles" );
 
     # test reverse relationship
+  SKIP: {
+        skip "user is a reserved word in Pg so joins against User fail", 1
+          if $self->schema->storage->sqlt_type eq 'PostgreSQL';
 
-    my %users_expected = (
-        user   => { count => 2 },
-        admin  => { count => 1 },
-        editor => { count => 2 },
-    );
+        my %users_expected = (
+            1 => { count => 2 },
+            2 => { count => 1 },
+            3 => { count => 2 },
+        );
 
-    foreach my $name ( keys %users_expected ) {
-        my $role     = $rset_role->find( { name => $name } );
-        my $count    = $role->users->count;
-        my $expected = $users_expected{$name}->{count};
+        my $roles_iter = $self->schema->resultset('Role')->search;
 
-        if ( $name eq 'user' ) {
-            $expected = $rset_user->count;
+        while ( my $role = $roles_iter->next ) {
+            my $count    = $role->users->count;
+            my $expected = $users_expected{ $role->id }->{count};
+
+            cmp_ok( $count, '==', $expected,
+                "Test user count for role " . $role->name );
         }
-        cmp_ok( $count, '==', $expected, "Test user count for role " . $name );
     }
 
     # cleanup
     $self->clear_users;
-    $role_user->delete;
-    $role_editor->delete;
 };
 
 1;
